# Tab

A tab in a document.

**Type:** object

## Properties

- **tabProperties** ([TabProperties](tabproperties.md)): The properties of the tab, like ID and title.
- **childTabs** (array of [Tab](tab.md)): The child tabs nested within this tab.
- **documentTab** ([DocumentTab](documenttab.md)): A tab with document contents, like text and images.
